@@ -198,7 +198,7 @@ AddOn.prototype.initPreferencePage = function() {
         WidgetFactory.restoreState(widget);
         WidgetFactory.saveState(widget);
         WidgetFactory.requiresRestart = false;
-        widget.destroy();
+        destr(widget);
 
         RSettings.setValue(settingsKey, true);
     }
@@ -525,7 +525,12 @@ AddOn.getAddOns = function(dir) {
         var fileInfo = new QFileInfo(dirInfo.filePath() + "/" + dirInfo.fileName() + ".js");
 
         if (dirInfo.fileName().startsWith("AutoLoad")) {
-            RAutoLoadEcma.addAutoLoadFile(fileInfo.filePath());
+            if (typeof(RAutoLoadEcma)!=="undefined") {
+                RAutoLoadEcma.addAutoLoadFile(fileInfo.filePath());
+            }
+            if (typeof(RAutoLoadJs)!=="undefined") {
+                RAutoLoadJs.addAutoLoadFile(fileInfo.filePath());
+            }
         }
         else {
             if (fileInfo.exists() && !AddOn.isIgnored(fileInfo.absoluteFilePath())) {
